@@ -2,14 +2,20 @@ use strict;
 use warnings;
 use feature ":all";
 
+use File::Basename qw<dirname>;
+
 use Template::Plex;
 
 my %hash=(title=>"hello");
-my @options=(root=>"examples");
-my $template=plex "recursive-top.plex";#, "";#, {};#\%hash;#, @options;
+
+my $root=dirname __FILE__;
+
+my @options=(root=>$root);
+
+my $template=plex "recursive-top.plex", {}, @options;
 
 $hash{title}="goodbye";
-say $template;
+say $template->render;
 #say $template->render({title=>"jacky"});
 
 
